==> navigine_sdk-0.0.1.tar.gz: example/lib/location_detail.dart <==
import 'package:flutter/material.dart';
import 'package:navigine_sdk/navigine_sdk.dart';

class LocationImage extends StatefulWidget {
  final SubLocation subLocation;
  final Function(Offset) onTap;
  LocationImage({this.subLocation, this.onTap});
  @override
  _LocationImageState createState() => _LocationImageState();
}

class _LocationImageState extends State<LocationImage> {
  @override
  Widget build(BuildContext context) {
    return ClipRect(
      child: Container()
    );

    // GestureDetector(
    //    onScaleUpdate: (ScaleUpdateDetails scaleDetails) {
    //      print(scaleDetails.scale);
    //   },
    //   onTapUp: (detail) {
    //     RenderBox box = context.findRenderObject();
    //     Size imageSize = box.size;
    //     Offset local = box.globalToLocal(detail.globalPosition);

    //     Offset k = Offset(
    //       local.dx / imageSize.width,
    //       1 - local.dy / imageSize.height,
    //     );
    //     print(k);
    //     // widget.onTap(local);
    //   },
    //   child:,
    // );
  }
}

class LocationDetail extends StatefulWidget {
  final Location location;
  final NavigineSDK navigine;
  LocationDetail({this.location, this.navigine});
  @override
  _LocationDetailState createState() => _LocationDetailState();
}

class _LocationDetailState extends State<LocationDetail> {
  Location location;
  SubLocation selected;

  initState() {
    super.initState();
    location = widget.location;

    loadLocation();
  }

  loadLocation() async {
    widget.navigine.loadLocation(
        locationId: location.id,
        onSuccess: (Location location) {
          setState(() {
            this.location = location;
          });
        });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(location.name),
      ),
      floatingActionButton: FloatingActionButton.extended(
        icon: Icon(Icons.add),
        label: Text("CREATE NEW SUB LOCATION"),
        onPressed: () {},
      ),
      body: Column(
        children: [
          Container(
            color: Colors.blue.withOpacity(.5),
            padding: EdgeInsets.fromLTRB(10, 0, 10, 0),
            child: DropdownButtonHideUnderline(
              child: DropdownButton(
                hint: Text("Select sub-location"),
                value: selected,
                isExpanded: true,
                onChanged: (value) {
                  setState(() {
                    selected = value;
                  });
                },
                items: location.subLocations
                    .map<DropdownMenuItem>((sl) => DropdownMenuItem(
                          child: Text(sl.name),
                          value: sl,
                        ))
                    .toList(),
              ),
            ),
          ),
          Expanded(
            child: Column(children: [
              selected == null
                  ? SizedBox()
                  : Container(
                      height: 400,
                      child: LocationImage(
                        subLocation: selected,
                        onTap: (position) {},
                      ),
                    )
            ]),
          ),
        ],
      ),
    );
  }
}

==> navigine_sdk-1.1.0.tar.gz: example/lib/location_detail.dart <==
import 'package:flutter/material.dart';
import 'package:navigine_sdk/navigine_sdk.dart';

class LocationImage extends StatefulWidget {
  final SubLocation subLocation;
  final Function(Offset)? onTap;
  LocationImage({
    required this.subLocation,
    this.onTap,
  });
  @override
  _LocationImageState createState() => _LocationImageState();
}

class _LocationImageState extends State<LocationImage> {
  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onScaleUpdate: (ScaleUpdateDetails scaleDetails) {
        print(scaleDetails.scale);
      },
      onTapUp: (detail) {
        RenderBox? box = context.findRenderObject() as RenderBox?;

        if (box == null) return;

        Size? imageSize = context.size;

        if (imageSize == null) return;

        Offset local = box.globalToLocal(detail.globalPosition);

        // Offset k = Offset(
        //   local.dx / imageSize.width,
        //   1 - local.dy / imageSize.height,
        // );

        widget.onTap?.call(local);
      },
      child: Image.memory(widget.subLocation.image!),
    );
  }
}

class LocationDetail extends StatefulWidget {
  final Location location;
  final NavigineSDK navigine;
  LocationDetail({
    required this.location,
    required this.navigine,
  });
  @override
  _LocationDetailState createState() => _LocationDetailState();
}

class _LocationDetailState extends State<LocationDetail> {
  late Location location;
  SubLocation? selected;

  initState() {
    super.initState();
    location = widget.location;
    loadLocation();
  }

  loadLocation() async {
    widget.navigine.loadLocation(
      locationId: location.id,
      onSuccess: (Location location) {
        setState(() {
          this.location = location;
        });
      },
    );
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(location.name),
      ),
      floatingActionButton: FloatingActionButton.extended(
        icon: Icon(Icons.add),
        label: Text("CREATE NEW SUB LOCATION"),
        onPressed: () {},
      ),
      body: Column(
        children: [
          Container(
            color: Colors.blue.withOpacity(.5),
            padding: EdgeInsets.fromLTRB(10, 0, 10, 0),
            child: DropdownButtonHideUnderline(
              child: DropdownButton<SubLocation>(
                hint: Text("Select sub-location"),
                value: selected,
                isExpanded: true,
                onChanged: (value) {
                  setState(() {
                    selected = value;
                  });
                },
                items: location.subLocations
                    .map(
                      (sl) => DropdownMenuItem(
                        child: Text(sl.name),
                        value: sl,
                      ),
                    )
                    .toList(),
              ),
            ),
          ),
          Expanded(
            child: Column(children: [
              selected == null
                  ? SizedBox()
                  : Container(
                      height: 400,
                      child: LocationImage(
                        subLocation: selected!,
                        onTap: (position) {},
                      ),
                    )
            ]),
          ),
        ],
      ),
    );
  }
}
